==> v1.0.4.tar.gz: djs-button-pages/src/Classes/Buttons/CustomButton.ts <==
/**
 * Copyright © 2022 Danila Kononov (nickname: moony). All rights reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { MessageButton } from "discord.js";
import ButtonAction from "../../Typings/ButtonAction";
import ButtonDisableWhen from "../../Typings/ButtonDisableWhen";
import ButtonData from "./Abstract/ButtonData";

/**
 * Custom button. Helps to create buttons with custom actions.
 */
class CustomButton extends ButtonData
{
    /**
     * Custom button. Helps to create buttons with custom actions.
     * @param {MessageButton} style Button style.
     */
    public constructor(style?:MessageButton)
    {
        super();

        if (style)
            this.setStyle(style);
    };

    /**
     * Sets button action.
     * @param {ButtonAction} action Either a number of a page or a function that determines number of a page.
     * @returns {this} Button data.
     */
    public setAction(action: ButtonAction): this
    {
        if (typeof action === "number" && (!Number.isInteger(action) || action < 0))
            throw new RangeError("Action should return natural number.");

        this._setAction(action);

        return this;
    };

    /**
     * Sets condition of disabling button.
     * @param {ButtonDisableWhen} action Either a number of a page or a function that determines number of a page.
     * @returns {this} Button data.
     */
    public setDisableWhen(disableWhen: ButtonDisableWhen): this
    {
        if (typeof disableWhen === "number" && (!Number.isInteger(disableWhen) || disableWhen < -1))
            throw new RangeError("Action should return natural number or minus one to be always turned on.");

        this._setDisableWhen(disableWhen);

        return this;
    };
};

export default CustomButton;

==> v2.0.2.tar.gz: djs-button-pages/src/Classes/Buttons/CustomButton.ts <==
/**
 * Copyright © 2022 Danila Kononov (nickname: moony). All rights reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { MessageButton } from "discord.js";
import ButtonAction from "../../Typings/ButtonAction";
import ButtonDisableWhen from "../../Typings/ButtonDisableWhen";
import ButtonData from "./Abstract/ButtonData";

/**
 * Button with custom set of scripts.
 */
class CustomButton extends ButtonData
{
    /**
     * Button with custom set of scripts.
     * @param {MessageButton} style Button style.
     */
    public constructor(style?:MessageButton)
    {
        super(style);
    };

    /**
     * Sets an action that should be completed when the button is pressed.
     * @param {ButtonAction} action Either a number of a page or a function that determines number of a page.
     * @returns {this} Button data.
     */
    public setAction(action: ButtonAction): this
    {
        return this._setAction(action);
    };

    /**
     * Sets a condition of disabling button.
     * @param {ButtonDisableWhen} disableWhen Either a number of a page or a function that determines number of a page.
     * @returns {this} Button data.
     */
    public setDisableWhen(disableWhen: ButtonDisableWhen): this
    {
        return this._setDisableWhen(disableWhen);
    };
};

export default CustomButton;
